==> blesta-5.10.2.zip: blesta/plugins/support_manager/language/uk_ua/support_manager_departments.php <==
<?php
/**
 * Support Manager Departments
 *
 * @package blesta
 * @subpackage blesta.language.uk_ua
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['SupportManagerDepartments.priorities.medium'] = 'Середній';
$lang['SupportManagerDepartments.reminder_intervals.minutes'] = '%1$s Хвилини';
$lang['SupportManagerDepartments.reminder_intervals.hours'] = '%1$s Годин';
$lang['SupportManagerDepartments.reminder_intervals.hour'] = '1 година';
$lang['SupportManagerDepartments.ticket_intervals.days'] = '%1$s днів';
$lang['SupportManagerDepartments.ticket_intervals.day'] = '1 день';
$lang['SupportManagerDepartments.visibility_options.staff'] = 'Тільки для персоналу';
$lang['SupportManagerDepartments.visibility_options.client'] = 'Клієнт і персонал';
$lang['SupportManagerDepartments.field_types.password'] = 'Пароль';
$lang['SupportManagerDepartments.field_types.textarea'] = 'Текстова область';
$lang['SupportManagerDepartments.field_types.text'] = 'Текст';
$lang['SupportManagerDepartments.field_types.quantity'] = 'Кількість';
$lang['SupportManagerDepartments.field_types.select'] = 'Випадаюче меню';
$lang['SupportManagerDepartments.field_types.radio'] = 'Радіо';
$lang['SupportManagerDepartments.field_types.checkbox'] = 'Прапорець';
$lang['SupportManagerDepartments.message_types.deleted'] = 'Видалено';
$lang['SupportManagerDepartments.message_types.read'] = 'Прочитайте';
$lang['SupportManagerDepartments.security_types.tls'] = 'TLS';
$lang['SupportManagerDepartments.security_types.ssl'] = 'SSL';
$lang['SupportManagerDepartments.security_types.none'] = 'Ні.';
$lang['SupportManagerDepartments.priorities.low'] = 'Низький';
$lang['SupportManagerDepartments.priorities.high'] = 'Високий';
$lang['SupportManagerDepartments.priorities.critical'] = 'Критично важливо.';
$lang['SupportManagerDepartments.priorities.emergency'] = 'Надзвичайна ситуація';
$lang['SupportManagerDepartments.statuses.visible'] = 'Видимий';
$lang['SupportManagerDepartments.statuses.hidden'] = 'Приховано';
$lang['SupportManagerDepartments.methods.imap'] = 'IMAP';
$lang['SupportManagerDepartments.methods.pop3'] = 'POP3';
$lang['SupportManagerDepartments.methods.pipe'] = 'Трубопровід';
$lang['SupportManagerDepartments.methods.none'] = 'Ні.';
$lang['SupportManagerDepartments.!error.department_id.has_tickets'] = 'Відділ не міг бути видалений, оскільки на даний момент за ним закріплені квитки.';
$lang['SupportManagerDepartments.!error.auto_delete.format'] = 'Чи потрібно автоматично видаляти дані поля після закриття тікета, має бути встановлено в 0 або 1.';
$lang['SupportManagerDepartments.!error.encrypted.format'] = 'Чи потрібно шифрувати дані поля, має бути встановлено на 0 або 1.';
$lang['SupportManagerDepartments.!error.client_add.format'] = 'Чи дозволяти клієнту додавати, має бути встановлено на 0 або 1.';
$lang['SupportManagerDepartments.!error.type.format'] = 'Будь ласка, виберіть правильний тип поля.';
$lang['SupportManagerDepartments.!error.visibility.format'] = 'Будь ласка, виберіть дійсний статус видимості.';
$lang['SupportManagerDepartments.!error.label.empty'] = 'Будь ласка, введіть етикетку.';
$lang['SupportManagerDepartments.!error.department_id.exists'] = 'Невірний ідентифікатор відділу.';
$lang['SupportManagerDepartments.!error.status.format'] = 'Неправильний тип статусу.';
$lang['SupportManagerDepartments.!error.response_id.format'] = 'Будь ласка, виберіть правильну відповідь для автоматичного закриття.';
$lang['SupportManagerDepartments.!error.max_attachment_size.format'] = 'Максимальний розмір вкладення має бути числовим значенням.';
$lang['SupportManagerDepartments.!error.attachment_types.length'] = 'Список типів вкладень не може перевищувати 255 символів.';
$lang['SupportManagerDepartments.!error.include_attachments.format'] = 'Чи включати додатки до квитків, має бути встановлено на 0 або 1.';
$lang['SupportManagerDepartments.!error.reminder_ticket_priority.format'] = 'Будь ласка, оберіть дійсний пріоритет нагадування про квиток.';
$lang['SupportManagerDepartments.!error.reminder_ticket_status.format'] = 'Будь ласка, оберіть дійсний статус нагадування про квиток.';
$lang['SupportManagerDepartments.!error.reminder_ticket_interval.format'] = 'Будь ласка, оберіть дійсний інтервал нагадування.';
$lang['SupportManagerDepartments.!error.delete_ticket_interval.format'] = 'Будь ласка, виберіть дійсний інтервал видалення квитків.';
$lang['SupportManagerDepartments.!error.close_ticket_interval.format'] = 'Будь ласка, оберіть дійсний інтервал для закриття квитків.';
$lang['SupportManagerDepartments.!error.send_ticket_received.format'] = 'Чи надсилати електронні листи з підтвердженням квитків для цього відділу, має бути встановлено на 0 або 1.';
$lang['SupportManagerDepartments.!error.override_from_email.format'] = 'Чи дозволити використовувати електронну адресу цього відділу в якості адреси відправника в шаблонах листів, має бути встановлено на 0 або 1.';
$lang['SupportManagerDepartments.!error.require_captcha.format'] = 'Чи вимагати перевірку людиною, має бути встановлено на 0 або 1.';
$lang['SupportManagerDepartments.!error.clients_only.format'] = 'Чи дозволяти клієнтам відкривати тікети або відповідати на них, має бути встановлено на 0 або 1.';
$lang['SupportManagerDepartments.!error.mark_messages.valid'] = 'Повідомлення, що використовують POP3, можуть бути позначені лише як видалені.';
$lang['SupportManagerDepartments.!error.mark_messages.format'] = 'Будь ласка, виберіть правильний тип повідомлення для позначення повідомлень.';
$lang['SupportManagerDepartments.!error.security.format'] = 'Будь ласка, оберіть дійсний тип безпеки.';
$lang['SupportManagerDepartments.!error.service.format'] = 'Будь ласка, оберіть правильний тип послуги.';
$lang['SupportManagerDepartments.!error.port.length'] = 'Довжина порту не може перевищувати 6 цифр.';
$lang['SupportManagerDepartments.!error.port.format'] = 'Будь ласка, введіть номер порту.';
$lang['SupportManagerDepartments.!error.password.format'] = 'Будь ласка, введіть пароль.';
$lang['SupportManagerDepartments.!error.user.length'] = 'Довжина імені користувача не може перевищувати 64 символів.';
$lang['SupportManagerDepartments.!error.user.format'] = 'Будь ласка, введіть ім\'я користувача.';
$lang['SupportManagerDepartments.!error.host.length'] = 'Ім\'я хоста не може перевищувати 128 символів у довжину.';
$lang['SupportManagerDepartments.!error.host.format'] = 'Будь ласка, введіть дійсне ім\'я хоста.';
$lang['SupportManagerDepartments.!error.default_priority.format'] = 'Неправильний тип пріоритету за замовчуванням.';
$lang['SupportManagerDepartments.!error.method.mailparse'] = 'Розширення PHP Mailparse PECL необхідне для розбору квитків електронної пошти.';
$lang['SupportManagerDepartments.!error.method.imap'] = 'Розширення PHP IMAP необхідне для завантаження повідомлень через POP3 або IMAP.';
$lang['SupportManagerDepartments.!error.method.format'] = 'Неправильний тип методу.';
$lang['SupportManagerDepartments.!error.email.format'] = 'Будь ласка, введіть дійсну адресу електронної пошти.';
$lang['SupportManagerDepartments.!error.description.empty'] = 'Будь ласка, введіть опис.';
$lang['SupportManagerDepartments.!error.name.empty'] = 'Будь ласка, введіть назву цього відділу.';
$lang['SupportManagerDepartments.!error.company_id.exists'] = 'Невірний ідентифікатор компанії.';

==> blesta-5.11.4.zip: blesta/plugins/support_manager/language/uk_ua/support_manager_departments.php <==
<?php
/**
 * Support Manager Departments
 *
 * @package blesta
 * @subpackage blesta.language.uk_ua
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['SupportManagerDepartments.priorities.medium'] = 'Середній';
$lang['SupportManagerDepartments.reminder_intervals.minutes'] = '%1$s Хвилини';
$lang['SupportManagerDepartments.reminder_intervals.hours'] = '%1$s Годин';
$lang['SupportManagerDepartments.reminder_intervals.hour'] = '1 година';
$lang['SupportManagerDepartments.ticket_intervals.days'] = '%1$s днів';
$lang['SupportManagerDepartments.ticket_intervals.day'] = '1 день';
$lang['SupportManagerDepartments.visibility_options.staff'] = 'Тільки для персоналу';
$lang['SupportManagerDepartments.visibility_options.client'] = 'Клієнт і персонал';
$lang['SupportManagerDepartments.field_types.password'] = 'Пароль';
$lang['SupportManagerDepartments.field_types.textarea'] = 'Текстова область';
$lang['SupportManagerDepartments.field_types.text'] = 'Текст';
$lang['SupportManagerDepartments.field_types.quantity'] = 'Кількість';
$lang['SupportManagerDepartments.field_types.select'] = 'Випадаюче меню';
$lang['SupportManagerDepartments.field_types.radio'] = 'Радіо';
$lang['SupportManagerDepartments.field_types.checkbox'] = 'Прапорець';
$lang['SupportManagerDepartments.message_types.deleted'] = 'Видалено';
$lang['SupportManagerDepartments.message_types.read'] = 'Прочитайте';
$lang['SupportManagerDepartments.security_types.tls'] = 'TLS';
$lang['SupportManagerDepartments.security_types.ssl'] = 'SSL';
$lang['SupportManagerDepartments.security_types.none'] = 'Ні.';
$lang['SupportManagerDepartments.priorities.low'] = 'Низький';
$lang['SupportManagerDepartments.priorities.high'] = 'Високий';
$lang['SupportManagerDepartments.priorities.critical'] = 'Критично важливо.';
$lang['SupportManagerDepartments.priorities.emergency'] = 'Надзвичайна ситуація';
$lang['SupportManagerDepartments.statuses.visible'] = 'Видимий';
$lang['SupportManagerDepartments.statuses.hidden'] = 'Приховано';
$lang['SupportManagerDepartments.methods.imap'] = 'IMAP';
$lang['SupportManagerDepartments.methods.pop3'] = 'POP3';
$lang['SupportManagerDepartments.methods.pipe'] = 'Трубопровід';
$lang['SupportManagerDepartments.methods.none'] = 'Ні.';
$lang['SupportManagerDepartments.!error.department_id.has_tickets'] = 'Відділ не міг бути видалений, оскільки на даний момент за ним закріплені квитки.';
$lang['SupportManagerDepartments.!error.auto_delete.format'] = 'Чи потрібно автоматично видаляти дані поля після закриття тікета, має бути встановлено в 0 або 1.';
$lang['SupportManagerDepartments.!error.encrypted.format'] = 'Чи потрібно шифрувати дані поля, має бути встановлено на 0 або 1.';
$lang['SupportManagerDepartments.!error.client_add.format'] = 'Чи дозволяти клієнту додавати, має бути встановлено на 0 або 1.';
$lang['SupportManagerDepartments.!error.type.format'] = 'Будь ласка, виберіть правильний тип поля.';
$lang['SupportManagerDepartments.!error.visibility.format'] = 'Будь ласка, виберіть дійсний статус видимості.';
$lang['SupportManagerDepartments.!error.label.empty'] = 'Будь ласка, введіть етикетку.';
$lang['SupportManagerDepartments.!error.department_id.exists'] = 'Невірний ідентифікатор відділу.';
$lang['SupportManagerDepartments.!error.status.format'] = 'Неправильний тип статусу.';
$lang['SupportManagerDepartments.!error.response_id.format'] = 'Будь ласка, виберіть правильну відповідь для автоматичного закриття.';
$lang['SupportManagerDepartments.!error.max_attachment_size.format'] = 'Максимальний розмір вкладення має бути числовим значенням.';
$lang['SupportManagerDepartments.!error.attachment_types.length'] = 'Список типів вкладень не може перевищувати 255 символів.';
$lang['SupportManagerDepartments.!error.include_attachments.format'] = 'Чи включати додатки до квитків, має бути встановлено на 0 або 1.';
$lang['SupportManagerDepartments.!error.reminder_ticket_priority.format'] = 'Будь ласка, оберіть дійсний пріоритет нагадування про квиток.';
$lang['SupportManagerDepartments.!error.reminder_ticket_status.format'] = 'Будь ласка, оберіть дійсний статус нагадування про квиток.';
$lang['SupportManagerDepartments.!error.reminder_ticket_interval.format'] = 'Будь ласка, оберіть дійсний інтервал нагадування.';
$lang['SupportManagerDepartments.!error.delete_ticket_interval.format'] = 'Будь ласка, виберіть дійсний інтервал видалення квитків.';
$lang['SupportManagerDepartments.!error.close_ticket_interval.format'] = 'Будь ласка, оберіть дійсний інтервал для закриття квитків.';
$lang['SupportManagerDepartments.!error.send_ticket_received.format'] = 'Чи надсилати електронні листи з підтвердженням квитків для цього відділу, має бути встановлено на 0 або 1.';
$lang['SupportManagerDepartments.!error.override_from_email.format'] = 'Чи дозволити використовувати електронну адресу цього відділу в якості адреси відправника в шаблонах листів, має бути встановлено на 0 або 1.';
$lang['SupportManagerDepartments.!error.require_captcha.format'] = 'Чи вимагати перевірку людиною, має бути встановлено на 0 або 1.';
$lang['SupportManagerDepartments.!error.clients_only.format'] = 'Чи дозволяти клієнтам відкривати тікети або відповідати на них, має бути встановлено на 0 або 1.';
$lang['SupportManagerDepartments.!error.mark_messages.valid'] = 'Повідомлення, що використовують POP3, можуть бути позначені лише як видалені.';
$lang['SupportManagerDepartments.!error.mark_messages.format'] = 'Будь ласка, виберіть правильний тип повідомлення для позначення повідомлень.';
$lang['SupportManagerDepartments.!error.security.format'] = 'Будь ласка, оберіть дійсний тип безпеки.';
$lang['SupportManagerDepartments.!error.service.format'] = 'Будь ласка, оберіть правильний тип послуги.';
$lang['SupportManagerDepartments.!error.port.length'] = 'Довжина порту не може перевищувати 6 цифр.';
$lang['SupportManagerDepartments.!error.port.format'] = 'Будь ласка, введіть номер порту.';
$lang['SupportManagerDepartments.!error.password.format'] = 'Будь ласка, введіть пароль.';
$lang['SupportManagerDepartments.!error.user.length'] = 'Довжина імені користувача не може перевищувати 64 символів.';
$lang['SupportManagerDepartments.!error.user.format'] = 'Будь ласка, введіть ім\'я користувача.';
$lang['SupportManagerDepartments.!error.host.length'] = 'Ім\'я хоста не може перевищувати 128 символів у довжину.';
$lang['SupportManagerDepartments.!error.host.format'] = 'Будь ласка, введіть дійсне ім\'я хоста.';
$lang['SupportManagerDepartments.!error.default_priority.format'] = 'Неправильний тип пріоритету за замовчуванням.';
$lang['SupportManagerDepartments.!error.method.mailparse'] = 'Розширення PHP Mailparse PECL необхідне для розбору квитків електронної пошти.';
$lang['SupportManagerDepartments.!error.method.imap'] = 'Розширення PHP IMAP необхідне для завантаження повідомлень через POP3 або IMAP.';
$lang['SupportManagerDepartments.!error.method.format'] = 'Неправильний тип методу.';
$lang['SupportManagerDepartments.!error.email.format'] = 'Будь ласка, введіть дійсну адресу електронної пошти.';
$lang['SupportManagerDepartments.!error.description.empty'] = 'Будь ласка, введіть опис.';
$lang['SupportManagerDepartments.!error.name.empty'] = 'Будь ласка, введіть назву цього відділу.';
$lang['SupportManagerDepartments.!error.company_id.exists'] = 'Невірний ідентифікатор компанії.';
$lang['SupportManagerDepartments.!error.priorities[].format'] = 'Один або декілька пріоритетів є недійсними.';
$lang['SupportManagerDepartments.!error.priorities[].empty'] = 'Виберіть хоча б один пріоритет.';
